==> content_snapshot-3.0.x-dev.tar.gz: content_snapshot/tests/src/Functional/AbstractFunctional.php <==
<?php

namespace Drupal\Tests\content_snapshot\Functional;

use Drupal\content_snapshot\SnapshotWriter\SnapshotWriter;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Serialization\Yaml;
use Drupal\Tests\BrowserTestBase;
use Drush\TestTraits\DrushTestTrait;

/**
 * Abstract class providing features making functional testing easier.
 */
abstract class AbstractFunctional extends BrowserTestBase {

  use DrushTestTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * EntityTypeManager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Filesystem.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $this->config = $configFactory->getEditable('content_snapshot.settings');
    $this->entityTypeManager = $this->container->get('entity_type.manager');
    $this->fileSystem = $this->container->get('file_system');

    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $this->config = $configFactory->getEditable('content_snapshot.settings');
  }

  /**
   * Helper method for preparing snapshot path.
   */
  protected function prepareSnapshotPath() {
    $tempDirectory = $this->fileSystem->getTempDirectory();
    $snapshotPath = "$tempDirectory/snapshot";

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = $this->fileSystem;

    $fileSystem->prepareDirectory($snapshotPath, FileSystemInterface::CREATE_DIRECTORY);
    $fileSystem->saveData('', $fileSystem->createFilename('.snapshot', $snapshotPath));

    return $snapshotPath;
  }

  /**
   * Helper method for setting up snapshot path and saving it in configuration.
   */
  protected function setUpSnapshotPath() {
    $snapshotPath = $this->prepareSnapshotPath();
    $this->config->set('snapshot_path', $snapshotPath);
    $this->config->save();
  }

  /**
   * Helper method for validating snapshot.
   *
   * @param string $snapshotPath
   *   Path where snapshot is supposed to be stored.
   */
  protected function validateSnapshot(string $snapshotPath) {

    $shapshotDataPath = "$snapshotPath/" . SnapshotWriter::DATA_DIR;

    $fileSystem = $this->fileSystem;
    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');
    // Check if produced snapshot items are valid yaml files.
    foreach ($results as $path => $result) {
      try {
        Yaml::decode(file_get_contents($path));
      }
      catch (\Exception $e) {
        self::assertTrue(FALSE, "Checks if snapshot item is a valid YAML file.");
      }
    }
  }

  /**
   * Helper method.
   *
   * Making sure that snapshot doesn't change after
   * export-import-export cycle.
   */
  protected function assertSnapshotConsistency() {
    $this->drush('-y content-snapshot:export');

    $snapshotPath = $this->config->get('snapshot_path');
    $shapshotDataPath = "$snapshotPath/" . SnapshotWriter::DATA_DIR;

    $fileSystem = $this->fileSystem;
    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');

    $contents = [];
    foreach ($results as $path => $result) {
      $contents[$path] = file_get_contents($path);
    }

    $this->runSnapshotImport();
    $this->runSnapshotExport();

    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');
    foreach ($results as $path => $result) {
      self::assertEquals($contents[$path], file_get_contents($path));
    }
  }

  /**
   * Helper method.
   */
  protected function runSnapshotExportImport(?string $snapshotPath = NULL) {
    $this->runSnapshotExport($snapshotPath);
    $this->runSnapshotImport($snapshotPath);
  }

  /**
   * Helper method.
   */
  protected function runSnapshotExport(?string $snapshotPath = NULL) {
    $options = '';

    if ($snapshotPath) {
      $options .= "--snapshot-path=$snapshotPath";
    }

    $this->drush("-y content-snapshot:export $options");
  }

  /**
   * Helper method.
   */
  protected function runSnapshotImport(?string $snapshotPath = NULL) {
    $options = '';

    if ($snapshotPath) {
      $options .= "--snapshot-path=$snapshotPath";
    }

    $this->drush("-y content-snapshot:import $options");
  }

}

==> content_snapshot-4.0.x-dev.tar.gz: content_snapshot/tests/src/Functional/AbstractFunctional.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\content_snapshot\Functional;

use Drupal\content_snapshot\SnapshotWriter\SnapshotWriter;
use Drupal\Core\File\FileSystemInterface;
use Drupal\Component\Serialization\Yaml;
use Drupal\Tests\BrowserTestBase;
use Drush\TestTraits\DrushTestTrait;

/**
 * Abstract class providing features making functional testing easier.
 */
abstract class AbstractFunctional extends BrowserTestBase {

  use DrushTestTrait;

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * Configuration object.
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $config;

  /**
   * EntityTypeManager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Filesystem.
   *
   * @var \Drupal\Core\File\FileSystemInterface
   */
  protected $fileSystem;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $this->config = $configFactory->getEditable('content_snapshot.settings');
    $this->entityTypeManager = $this->container->get('entity_type.manager');
    $this->fileSystem = $this->container->get('file_system');

    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $this->config = $configFactory->getEditable('content_snapshot.settings');
  }

  /**
   * Helper method for preparing snapshot path.
   */
  protected function prepareSnapshotPath() {
    $tempDirectory = $this->fileSystem->getTempDirectory();
    $snapshotPath = "$tempDirectory/snapshot";

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = $this->fileSystem;

    $fileSystem->prepareDirectory($snapshotPath, FileSystemInterface::CREATE_DIRECTORY);
    $fileSystem->saveData('', $fileSystem->createFilename('.snapshot', $snapshotPath));

    return $snapshotPath;
  }

  /**
   * Helper method for setting up snapshot path and saving it in configuration.
   */
  protected function setUpSnapshotPath() {
    $snapshotPath = $this->prepareSnapshotPath();
    $this->config->set('snapshot_path', $snapshotPath);
    $this->config->save();
  }

  /**
   * Helper method for validating snapshot.
   *
   * @param string $snapshotPath
   *   Path where snapshot is supposed to be stored.
   */
  protected function validateSnapshot(string $snapshotPath) {

    $shapshotDataPath = "$snapshotPath/" . SnapshotWriter::DATA_DIR;

    $fileSystem = $this->fileSystem;
    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');
    // Check if produced snapshot items are valid yaml files.
    foreach ($results as $path => $result) {
      try {
        Yaml::decode(file_get_contents($path));
      }
      catch (\Exception) {
        self::assertTrue(FALSE, "Checks if snapshot item is a valid YAML file.");
      }
    }
  }

  /**
   * Helper method.
   *
   * Making sure that snapshot doesn't change after
   * export-import-export cycle.
   */
  protected function assertSnapshotConsistency() {
    $this->drush('-y content-snapshot:export');

    $snapshotPath = $this->config->get('snapshot_path');
    $shapshotDataPath = "$snapshotPath/" . SnapshotWriter::DATA_DIR;

    $fileSystem = $this->fileSystem;
    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');

    $contents = [];
    foreach ($results as $path => $result) {
      $contents[$path] = file_get_contents($path);
    }

    $this->runSnapshotImport();
    $this->runSnapshotExport();

    $results = $fileSystem->scanDirectory($shapshotDataPath, '/.*/');
    foreach ($results as $path => $result) {
      self::assertEquals($contents[$path], file_get_contents($path));
    }
  }

  /**
   * Helper method.
   */
  protected function runSnapshotExportImport(?string $snapshotPath = NULL) {
    $this->runSnapshotExport($snapshotPath);
    $this->runSnapshotImport($snapshotPath);
  }

  /**
   * Helper method.
   */
  protected function runSnapshotExport(?string $snapshotPath = NULL) {
    $options = '';

    if ($snapshotPath) {
      $options .= "--snapshot-path=$snapshotPath";
    }

    $this->drush("-y content-snapshot:export $options");
  }

  /**
   * Helper method.
   */
  protected function runSnapshotImport(?string $snapshotPath = NULL) {
    $options = '';

    if ($snapshotPath) {
      $options .= "--snapshot-path=$snapshotPath";
    }

    $this->drush("-y content-snapshot:import $options");
  }

}
